@@ -14,7 +14,7 @@ from fastapi import FastAPI
 from soco_cli.__init__ import __version__ as version
 from soco_cli.api import get_all_speaker_names
 from soco_cli.api import get_soco_object as get_speaker
-from soco_cli.api import rediscover_speakers, rescan_speakers
+from soco_cli.api import rescan_speakers
 from soco_cli.api import run_command as sc_run
 from soco_cli.utils import version as print_version
 
@@ -52,7 +52,7 @@ def command_core(speaker, action, *args, use_local=False):
 
     # Print the equivalent 'sonos' command and exit code
     if len(new_args) != 0:
-        arguments = (" ".join([arg for arg in new_args])).rstrip()
+        arguments = " ".join(new_args).rstrip()
         print(
             PREFIX
             + "Command = 'sonos {} {} {}', ".format(quoted_speaker, action, arguments),
@@ -149,16 +149,16 @@ def main():
         # Pre-load speaker cache
         print(PREFIX + "Finding speakers ... ", end="", flush=True)
         try:
-            # Try to discover a speaker that doesn't exist, to fully
-            # invoke speaker discovery
-            get_speaker("NULL_54983")
+            # This forces speaker discovery
+            # For some reason, using 'get_all_speakers()' provokes Uvicorn errors
+            get_speaker("")
             print(get_all_speaker_names())
         except:
             print("discovery failed, will retry on first request")
 
         # Start the server
         uvicorn.run(sc_app, host="0.0.0.0", use_colors=False, port=PORT)
-        print(INFO + " stopped")
+        print(PREFIX + INFO + " stopped")
         exit(0)
 
     except Exception as error:
